@@ -24,7 +24,7 @@ class Thor
           $stdin.gets
         else
           # Lazy-load io/console since it is gem-ified as of 2.3
-          require "io/console" if RUBY_VERSION > "1.9.2"
+          require "io/console"
           $stdin.noecho(&:gets)
         end
       end
